# Code of Conduct

First of all we really appreciate your interest and involvement in this project.

We define some basic rules for the participants of this community:

- Be respectful to others
- Try to help others
- Be open minded
- Have fun
